@@ -40,21 +40,22 @@ class TextRLEnv(gym.Env):
         return self._get_obs()
 
     def _get_obs(self, predicted=[]):
-        p_text = self.tokenizer.convert_tokens_to_string(predicted)
-        if len([k for k, v in self.model.named_parameters() if 'decoder' in k]) > 0:
-            feature_dict = self.tokenizer([self.input_text], return_tensors='pt', add_special_tokens=False).to(
-                self.model.device)
-            predicted = [self.tokenizer.eos_token] + predicted
-            dec_input = torch.tensor([self.tokenizer.convert_tokens_to_ids(predicted)]).to(self.model.device)
-            feature_dict['decoder_input_ids'] = dec_input
-            prediction = self.model(**feature_dict, output_hidden_states=True)
-            outputs = prediction.decoder_hidden_states[-1].squeeze(0)
-        else:
-            feature_dict = self.tokenizer([[self.input_text, p_text]], return_tensors='pt',
-                                          add_special_tokens=False).to(self.model.device)
-            prediction = self.model(**feature_dict, output_hidden_states=True)
-            prediction.hidden_states[-1].squeeze(0)
-        return outputs.data[-1]
+        with torch.no_grad():
+            p_text = self.tokenizer.convert_tokens_to_string(predicted)
+            if len([k for k, v in self.model.named_parameters() if 'decoder' in k]) > 0:
+                feature_dict = self.tokenizer([self.input_text], return_tensors='pt', add_special_tokens=False).to(
+                    self.model.device)
+                predicted = [self.tokenizer.eos_token] + predicted
+                dec_input = torch.tensor([self.tokenizer.convert_tokens_to_ids(predicted)]).to(self.model.device)
+                feature_dict['decoder_input_ids'] = dec_input
+                prediction = self.model(**feature_dict, output_hidden_states=True)
+                outputs = prediction.decoder_hidden_states[-1].squeeze(0)
+            else:
+                feature_dict = self.tokenizer([[self.input_text, p_text]], return_tensors='pt',
+                                              add_special_tokens=False).to(self.model.device)
+                prediction = self.model(**feature_dict, output_hidden_states=True)
+                outputs = prediction.hidden_states[-1].squeeze(0)
+            return outputs.data[-1]
 
     def _predict(self, vocab_id):
         predicted = self.predicted
